@@ -214,8 +214,8 @@ totem_playlist_mrl_to_title (const gchar *mrl)
 
 	filename = g_path_get_basename (mrl);
 	unescaped = gnome_vfs_unescape_string_for_display (filename);
-
 	g_free (filename);
+
 	filename_for_display = g_filename_to_utf8 (unescaped,
 			-1,             /* length */
 			NULL,           /* bytes_read */
@@ -226,8 +226,12 @@ totem_playlist_mrl_to_title (const gchar *mrl)
 	{
 		filename_for_display = g_locale_to_utf8 (unescaped,
 				-1, NULL, NULL, NULL);
-		if (filename_for_display == NULL)
-			return unescaped;
+		if (filename_for_display == NULL) {
+			filename_for_display = g_filename_display_name
+				(unescaped);
+		}
+		g_free (unescaped);
+		return filename_for_display;
 	}
 
 	g_free (unescaped);
@@ -247,6 +251,8 @@ totem_playlist_is_media (const char *mrl)
 		return TRUE;
 	if (g_str_has_prefix (mrl, "vcd:") != FALSE)
 		return TRUE;
+	if (g_str_has_prefix (mrl, "cd:") != FALSE)
+		return TRUE;
 
 	return FALSE;
 }
@@ -1365,6 +1371,7 @@ totem_playlist_init (TotemPlaylist *playlist)
 	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "dvd:");
 	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cdda:");
 	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "vcd:");
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cd:");
 
 	g_signal_connect (G_OBJECT (playlist->_priv->parser),
 			"entry",
